# -*- coding: utf-8 -*-

from guietta import _, ___, Gui, Quit, Exceptions


gui = Gui(
    
  [  'Enter numbers:', '__num1__' , '+' , '__num2__',  (['Calculate it'], 'foo') ],
  [  'Result:  -->'  , 'result'   , ___ ,  ___      ,       _        ],
  [  _               ,    _       ,  _  ,   _       ,      Quit      ],
  exceptions = Exceptions.POPUP)


with gui.foo:
    gui.result = float(gui.num1) + float(gui.num2)
     
gui.run()




from guietta import Gui, _, HSeparator, C, G, R, ___, III, QMessageBox


main = Gui(['<center>Dynamic layout demonstration</center'],
           [HSeparator],
           [   'label1'    , 'label2', ['Click here'] ],
           [G('Inner GUI') ,   ___   ,        _       ],
           [     III       ,   III   ,    'label4'    ],
           [   'label5'    , 'label6',        _       ])

subgui = Gui( [C('checkbox'), '__editbox__'],
              [R('radio')   ,  ['And here!']  ])

subgui.Andhere = lambda x: QMessageBox.information(None, "Clicked",
                           "The editbox contains "+subgui.editbox)

with main.Clickhere:
    if main.is_running:
        main.InnerGUI = subgui


main.run()
      



# -*- coding: utf-8 -*-

from guietta import _alsoAcceptAnotherGui

import pyqtgraph

if pyqtgraph.__version__ < '0.11.0':
    raise Exception('Minimum version for pyqtgraph is 0.11.0,'
                    'you have '+pyqtgraph.__version__)


class PyQtGraphPlotWidget(pyqtgraph.PlotWidget):
    def __init__(self, **kwargs):
        super().__init__()
        self.kwargs = kwargs

    def __guietta_property__(self):

        def getx():
            return self
    
        @_alsoAcceptAnotherGui(self)
        def setx(x):
            if x is None:
                return
    
            import numpy as np
            try:
                arr = np.array(x)
            except Exception as e:
                errmsg = 'pyqtgraph widgets need an array-like value'
                raise TypeError(errmsg) from e
    
            if len(arr.shape) == 1:
                self.plot(arr, clear=True)
                for k,v in self.kwargs.items():
                    getattr(self, k).__call__(v)
            else:
                raise ValueError('Value must be 1d, shape is %s instead'
                                 % str(arr.shape))
    
        return (getx, setx)


class PyQtGraphImageView(pyqtgraph.ImageView):
    def __init__(self, **kwargs):
        super().__init__()
        self.kwargs = kwargs

    def __guietta_property__(self):
        '''Property for pyqtgraph image widgets'''
    
        def getx():
            return self
    
        @_alsoAcceptAnotherGui(self)
        def setx(x):
            if x is None:
                return
    
            import numpy as np
            try:
                arr = np.array(x)
            except Exception as e:
                errmsg = 'pyqtgraph widgets need an array-like value'
                raise TypeError(errmsg) from e
    
            if len(arr.shape) == 2:
                self.setImage(arr)
                for k,v in self.kwargs.items():
                    getattr(self, k).__call__(v)
                self.getHistogramWidget().hide()
            else:
                raise ValueError('Value must be 2d, shape is %s instead'
                                 % str(arr.shape))
        return (getx, setx)

# ___oOo___



# -*- coding: utf-8 -*-

from guietta import Gui, P, Empty


gui = Gui(
    
  [  'Percent completed:', P('progress') ],
  
  title = 'ProgressBar test'

)

for counter in range(100):
    try:
        name, event = gui.get(timeout=0.1)
    except Empty:
        pass

    gui.progress = counter



# -*- coding: utf-8 -*-

from guietta import QFileDialog

filename = QFileDialog.getOpenFileName(None, "Open File",
                                             "/home",
                                             "Images (*.png *.xpm *.jpg *.jpeg)")

print(filename)



# -*- coding: utf-8 -*-

# Create three radio button groups and connect them
# in three different ways.

from guietta import Gui, _, R1, R2, R3

gui = Gui(

  [ R1('rad1',1),  R2('rad3')  , R3('rad5')   ],
  [ R1('rad2')  ,  R2('rad4')  , R3('rad6')   ],

)

def msg(gui, *args):
    print('second button group')

def event(gui, *args):
    print('third group')

gui.events(
    
   [   _        ,       _      ,   event   ],
   [   _        ,       _      ,   event   ],
   
)

with gui.rad1, gui.rad2:
    print('First button group')
    print('rad1 isChecked = ', gui.rad1.isChecked())
    print('rad2 isChecked = ', gui.rad2.isChecked())
    
gui.rad3 = msg
gui.rad4 = msg

gui.run()



# -*- coding: utf-8 -*-

import os.path
from guietta import B, L, _, Gui, Quit

gui = Gui(
    
  [  'Enter expression:', '__expr__'  , B('right.png', 'newname') ],
  [  L('left.png')      , 'result'    , _          ],
  [  _                  , _           , Quit       ],
  
  images_dir = os.path.dirname(__file__)
  
  )

while True:
    name, event = gui.get()
    print(name, event)
    if name == 'newname':
        try:
            gui.result = eval(gui.expr)
        except Exception as e:
            gui.result = 'Error: ' + str(e)

    elif name == None:
        break





# -*- coding: utf-8 -*-

# Demonstrates how to use Gui properties
# to connect a handler to a widget's default signal

from guietta import _, ___, Gui, Quit, Exceptions
        
gui = Gui(
    
  [  'Enter numbers:', '__num1__' , '+' , '__num2__',  ['Calculate'] ],
  [  'Result:  -->'  , 'result'   , ___ ,  ___      ,       _        ],
  [  _               ,    _       ,  _  ,   _       ,      Quit      ],
  exceptions = Exceptions.POPUP)


def calc(gui, *args):
    gui.result = float(gui.num1) + float(gui.num2)

# Assign a callable to the button

gui.Calculate = calc

gui.run()



# -*- coding: utf-8 -*-

# Showcase of most available widgets, also demonstrating how
# to integrate other QT widgets directly in the layout.
#
# Written by Bill Wetzel and Alfio Puglisi.

from guietta import Gui, B, E, L, HS, VS, HSeparator, VSeparator
from guietta import Yes, No, Ok, Cancel, Quit, _, ___, III
from guietta import R1, R2, C, P

try:
    from PySide2.QtWidgets import QDial, QLCDNumber, QTableWidget
    from PySide2.QtWidgets import QTableWidgetItem, QHeaderView
except ImportError:
    from PyQt5.QtWidgets import QDial, QLCDNumber, QTableWidget
    from PyQt5.QtWidgets import QTableWidgetItem, QHeaderView


gui = Gui(

  [ '<center>A big GUI with all of Guietta''s widgets</center>'],
  [ '<center>Move the dial!</center>'],
  [ HSeparator ],

  [ 'Label'    , 'imagelabel.jpeg' , L('another label')  , VS('slider1')],
  [  _         ,     ['button']    , B('another button') ,     III      ],
  [ '__edit__' ,  E('an edit box') , _                   ,   VSeparator ],
  [ R1('rad1') ,  R1('rad2')       , R1('rad3')          ,     III      ],
  [ R2('rad4') ,  R2('rad5')       , R2('rad6')          ,     III      ],
  [ C('ck1')   ,   C('ck2')        , C('ck3')            ,     III      ],
  [   Quit     ,        Ok         , Cancel              ,     III      ],
  [    Yes     ,        No         , _                   ,     III      ],
  [  HS('slider2'),    ___         , ___                 ,      _       ],
  [  (QDial, 'dial'),  (QLCDNumber, 'lcd')   , ___       ,      _       ],
  [  (QTableWidget, 'tab1'),  ___      , ___             ,      ___     ],
  [    III     , III , III , III ],
  [    III     , III , III , III ],
  [P('progbar'), (QLCDNumber, 'lcd2')   , _   ,  _    ],
  [   L('l1'),  L('l2'), L('l3'), L('l4')      ],
)

gui.window().setGeometry( 100, 100, 600, 900 )      # posx, posy, w, h

gui.widgets['dial'].setNotchesVisible( True )

gui.widgets['tab1'].setColumnCount( 4 )
gui.widgets['tab1'].setRowCount( 5 )
gui.widgets['tab1'].horizontalHeader().setSectionResizeMode(QHeaderView.Stretch)

gui.l1 = "Label 1"
gui.l2 = "This is Label 2"

for x in range( 4 ):
    for y in range( 5 ):
        item = QTableWidgetItem('%d %d' % (x, y))
        gui.widgets['tab1'].setItem( y, x, item )
        gui.widgets['tab1'].setHorizontalHeaderItem( x, QTableWidgetItem('Col: %d' % x ) )
        gui.widgets['tab1'].setVerticalHeaderItem( y, QTableWidgetItem('Row: %d' % y ) )

while True:
    name, event = gui.get()

    if name == 'slider1':
        gui.lcd.display( float(gui.slider1))
        gui.widgets['tab1'].itemAt( 0, 0 ).setText(str(gui.slider1))

    elif name == 'dial':
        gui.widgets['tab1'].itemAt( 0, 1 ).setText(str(gui.dial))
        gui.lcd2.display( float(gui.dial))
        gui.progbar = gui.dial

    elif name == None:
        break






from guietta import Gui, _, HSeparator, C, R, ___, III, QMessageBox


main = Gui(['<center>Dynamic layout demonstration</center'],
           [HSeparator],
           ['label1', 'label2', ['Click here'] ],
           ['label3',   ___   ,        _       ],
           [  III   ,   III   ,    'label4'    ],
           ['label5', 'label6',        _       ])

subgui = Gui( [C('checkbox'), '__editbox__'],
              [R('radio')   ,  ['And here!']  ])

subgui.Andhere = lambda x: QMessageBox.information(None, "Clicked",
                           "The editbox contains "+subgui.editbox)

with main.Clickhere:
    if main.is_running:
        main.label3 = subgui


main.run()
      
